aerosoltools.aerosol2d.Aerosol2D.convert_to_surface_concentration — aerosoltools 0.1.0 documentation

# aerosoltools.aerosol2d.Aerosol2D.convert_to_surface_concentration

Aerosol2D.convert_to_surface_concentration(inplace=True)

  Convert particle size distribution data to surface area concentration (nm²/cm³) based on the current data type.

  ## Parameters

  inplacebool, optional

    If True (default), modifies the current instance in-place. If False, returns a new instance with surface area concentration data.

  ## Returns

  self or aerosolxd

    Updated instance with surface area concentration data, either in-place or as a copy.

  Parameters:

    inplace (bool)